import {
  Body,
  Controller,
  Get,
  NotFoundException,
  Param,
  Post,
} from '@nestjs/common';
import { UserDocument } from '../../database/schemas/user.schema';
import { IsPublic } from '../auth/decorators/is-public.decorator';
import { UserCreateDto } from './user.dto';
import { UserService } from './user.service';

@Controller('/user')
export class UserController {
  constructor(private userService: UserService) {}

  @Get()
  @IsPublic()
  findAll(): Promise<UserDocument[]> {
    return this.userService.findAll();
  }

  @Get('/:id')
  @IsPublic()
  async findById(@Param('id') id: string): Promise<UserDocument> {
    const result = await this.userService.findById(id);
    if (!result) {
      throw new NotFoundException('Usuário não encontrado');
    }
    return result;
  }

  @IsPublic()
  @Post()
  create(@Body() dto: UserCreateDto): Promise<UserDocument> {
    return this.userService.create(dto);
  }
}
